@@ -78,9 +78,13 @@ class Jira(AtlassianRestAPI):
             self.issue(issuekey, fields='*none')
             log.info('Issue "{issuekey}" exists'.format(issuekey=issuekey))
             return True
-        except HTTPError:
-            log.info('Issue "{issuekey}" does not exists'.format(issuekey=issuekey))
-            return False
+        except HTTPError as e:
+            if e.response.status_code == 404:
+                log.info('Issue "{issuekey}" does not exists'.format(issuekey=issuekey))
+                return False
+            else:
+                log.info('Issue "{issuekey}" existsted, but now it\'s deleted'.format(issuekey=issuekey))
+                return True
 
     def issue_deleted(self, issuekey):
         try:
@@ -104,8 +108,9 @@ class Jira(AtlassianRestAPI):
     def issue_create_or_update(self, fields):
         issuekey = fields.get('issuekey', None)
 
-        if not issuekey:
-            log.info('Issuekey is not provided. Will attempt to create an issue')
+        if not issuekey or not self.issue_exists(issuekey):
+            log.info('Issuekey is not provided or does not exists in destination. Will attempt to create an issue')
+            del fields['issuekey']
             return self.issue_create(fields)
 
         if self.issue_deleted(issuekey):
@@ -140,4 +145,3 @@ class Jira(AtlassianRestAPI):
     def get_issue_status(self, issuekey):
         url = '/rest/api/2/issue/{issuekey}?fields=status'.format(issuekey=issuekey)
         return self.get(url)['fields']['status']['name']
-
